@@ -33,9 +33,10 @@
 #  define GRAVATAR_DEPRECATED_NO_EXPORT GRAVATAR_NO_EXPORT GRAVATAR_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define GRAVATAR_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef GRAVATAR_NO_DEPRECATED
+#    define GRAVATAR_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
